from calculator import Calculator

calc = Calculator()
calc.reset()
calc.add(2)  # Expected output: 2
calc.multiply(3)  # Expected output: 6
calc.root(2)  # Expected output: 2.449
calc.reset()
calc.subtract(5)  # Expected output: -5
calc.divide(2)  # Expected output: -2.5
